@@ -4,6 +4,8 @@ from .v1.broadcasts import BroadcastsEndpoint
 from .v1.events import EventsEndpoint
 from .v1.features import FeaturesEndpoint
 from .v1.places import PlacesEndpoint
+from .v1.radius import SuggestedRadiusEndpoint
+from .v1.beam import BeamEndpoint
 
 
 __all__ = [
@@ -13,4 +15,6 @@ __all__ = [
     "EventsEndpoint",
     "FeaturesEndpoint",
     "PlacesEndpoint",
+    "SuggestedRadiusEndpoint",
+    "BeamEndpoint",
 ]
