@@ -1,10 +1,12 @@
 from predicthq.endpoints.base import BaseEndpoint
 from predicthq.endpoints.decorators import accepts, returns
-from .schemas import AccessToken, GetTokenParams, RevokeTokenParams
+from .decorators import preload_config_defaults
+from .schemas import AccessToken
 
 
 class OAuth2Endpoint(BaseEndpoint):
-    @accepts(GetTokenParams)
+    @accepts()
+    @preload_config_defaults(["client_id", "client_secret", "scope", "grant_type"])
     @returns(AccessToken)
     def get_token(self, client_id, client_secret, scope, grant_type, **kwargs):
         verify_ssl = kwargs.pop("config.verify_ssl", True)
@@ -20,7 +22,8 @@ class OAuth2Endpoint(BaseEndpoint):
             verify=verify_ssl,
         )
 
-    @accepts(RevokeTokenParams)
+    @accepts()
+    @preload_config_defaults(["client_id", "client_secret", "token_type_hint"])
     def revoke_token(self, client_id, client_secret, token, token_type_hint, **kwargs):
         verify_ssl = kwargs.pop("config.verify_ssl", True)
         data = {
