@@ -1,16 +1,14 @@
 from predicthq.endpoints.base import UserBaseEndpoint
 from predicthq.endpoints.decorators import accepts, returns
 from .schemas import (
-    SearchParams,
     EventResultSet,
     CountResultSet,
-    CalendarParams,
     CalendarResultSet,
 )
 
 
 class EventsEndpoint(UserBaseEndpoint):
-    @accepts(SearchParams)
+    @accepts()
     @returns(EventResultSet)
     def search(self, **params):
         verify_ssl = params.pop("config.verify_ssl", True)
@@ -20,7 +18,7 @@ class EventsEndpoint(UserBaseEndpoint):
             verify=verify_ssl,
         )
 
-    @accepts(SearchParams)
+    @accepts()
     @returns(CountResultSet)
     def count(self, **params):
         verify_ssl = params.pop("config.verify_ssl", True)
@@ -30,7 +28,7 @@ class EventsEndpoint(UserBaseEndpoint):
             verify=verify_ssl,
         )
 
-    @accepts(CalendarParams)
+    @accepts()
     @returns(CalendarResultSet)
     def calendar(self, **params):
         verify_ssl = params.pop("config.verify_ssl", True)
